@@ -40,6 +40,7 @@ from awesomeversion.typing import VersionType
                 "1.0a12",
                 "1.0b1.dev456",
                 "1.0b2",
+                "1.0+local.1.2.3",
                 "1.0b2.post345.dev456",
                 "1.0b2.post345",
                 "1.0rc1.dev456",
@@ -47,6 +48,9 @@ from awesomeversion.typing import VersionType
                 "1.0.post456.dev34",
                 "1.0.post456",
                 "1.1.dev1",
+                "1.1-dev1",
+                "1.1dev1",
+                "1.1_dev1",
             )
         ],
         *[
